@@ -26,13 +26,12 @@ for i in range(1, 7):
     dir = os.path.join('tests', name)
     rawdex = read(os.path.join(dir, 'classes.dex'), 'rb')
 
-    for bits in range(256):
-        opts = options.Options(*[bool(bits & (1 << b)) for b in range(8)])
+    for opts in [options.NONE, options.PRETTY, options.ALL]:
         classes, errors = translate(rawdex, opts=opts)
         assert(not errors)
 
         for cls in classes.values():
-            print('{:08b}'.format(bits), hashlib.sha256(cls).hexdigest())
+            print('{:08b}'.format(0), hashlib.sha256(cls).hexdigest())
             fullhash = hashlib.sha256(fullhash + cls).digest()
 
 print('done!')
